/* iBeacon Module
 * --------------------------------------------------------------------------------------------------------------------------
 * Platform : i3pro
 * Developer : Pechyonkin Roman, iRidium LTD (email: pechyonkin.rs@gmail.com)
 * Creation date: 18.05.2016 
 * Description: With this module you can view iBeacon sensor parameters, such as RSSI level, distance and so. 
 *             Also you can create events for distance border entering/exiting
 * --------------------------------------------------------------------------------------------------------------------------
 * How to use: 
 *     You can create new beacon listener by creating BeaconListener class object. Example: 
          var cur_beacon = new BeaconListener(this_mac, this_power);
             where this_mac - beacon mac address, 
                   this_power - beacon tx_power value
 *     You can receive beacon parameters from this object, by using his properties, Example:
          cur_beacon.Name - beacon local name,
          cur_beacon.MAC - beacon mac address,
          cur_beacon.CurrentRSSI - last beacon rssi level,
          cur_beacon.AverageRSSI - average beacon rssi level,
          cur_beacon.Distance - distance behind beacon sensor and you (Warning: the distance can be calculated with an accuracy of 2 meters)
          cur_beacon.TXPower - tx power value of beacon
 *     Also most of this parameters can be viewed by relevant project tokens.
 *     You can create Event for this beacon, by executing AddEvent class method, Example: 
          cur_beacon.AddEvent(distance_parameter, enter_callback, exit_callback);
             where distance_parameter - distance border value in meters (for example 1.0 meter), 
                   enter_callback - function which will be executed if you enter in zone boundary,
                   exit_callback - function which will be executed if you exit in zone boundary.
 * --------------------------------------------------------------------------------------------------------------------------
 */


var this_mac = "71A3F497-995C-61F8-3766-81601CA6D422";
var this_power = -73;

IR.AddListener(IR.EVENT_START,0,function() {
   var cur_beacon = new BeaconListener(this_mac, this_power);
   
   cur_beacon.AddEvent(1.0, function() {
      IR.Log("Enter 1 meter zone");
   }, function() {
      IR.Log("Exit 1 meter zone");
   });
   
});
